@@ -114,18 +114,48 @@ cb_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 
 	GtkWidget *about;
+	GdkPixbuf *pixbuf;
+	GError    *error = NULL;
+	gchar     *file;
+
+
 	const gchar *authors[] = {
 				 _("Kevin Vandersloot (kfv101@psu.edu)"),
 				 _("Erik Johnsson (zaphod@linux.nu) - icon support"),
 				 NULL
 				 };
-				 
-	about = gnome_about_new (_("Process Manager"), VERSION,
+
+	const gchar *documenters[] = {
+				 NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
+	
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+				          "procman.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+	
+	g_free (file);
+
+			 
+	about = gnome_about_new (_("System Monitor"), VERSION,
 				 _("(C) 2001 Kevin Vandersloot"),
 				 _("Simple process viewer using libgtop"),
 				 authors,
-				 NULL, NULL, NULL);
-				 
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 pixbuf);
+	
+	if (pixbuf) {
+		g_object_unref (pixbuf);
+	}	
+
+			 
 	gtk_widget_show (about);  
 	
 }
@@ -135,7 +165,7 @@ void
 cb_app_exit (GtkObject *object, gpointer user_data)
 {
 	ProcData *procdata = user_data;
-	
+
 	cb_app_delete (NULL, NULL, procdata);
 	
 }
@@ -157,7 +187,7 @@ cb_app_delete (GtkWidget *window, GdkEventAny *event, gpointer data)
 		
 	gtk_main_quit ();
 	
-	return FALSE;
+	return TRUE;
 	
 }
 #if 0
